package cn.com.infosec.asn1.cmp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.crmf.CertId;
import cn.com.infosec.asn1.x509.X509Extensions;

public class RevAnnContent extends ASN1Encodable {
   private PKIStatus status;
   private CertId certId;
   private DERGeneralizedTime willBeRevokedAt;
   private DERGeneralizedTime badSinceDate;
   private X509Extensions crlDetails;

   private RevAnnContent(ASN1Sequence seq) {
      this.status = PKIStatus.getInstance(seq.getObjectAt(0));
      this.certId = CertId.getInstance(seq.getObjectAt(1));
      this.willBeRevokedAt = DERGeneralizedTime.getInstance(seq.getObjectAt(2));
      this.badSinceDate = DERGeneralizedTime.getInstance(seq.getObjectAt(3));
      if (seq.size() > 4) {
         this.crlDetails = X509Extensions.getInstance(seq.getObjectAt(4));
      }

   }

   public static RevAnnContent getInstance(Object o) {
      if (o instanceof RevAnnContent) {
         return (RevAnnContent)o;
      } else if (o instanceof ASN1Sequence) {
         return new RevAnnContent((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   public PKIStatus getStatus() {
      return this.status;
   }

   public CertId getCertId() {
      return this.certId;
   }

   public DERGeneralizedTime getWillBeRevokedAt() {
      return this.willBeRevokedAt;
   }

   public DERGeneralizedTime getBadSinceDate() {
      return this.badSinceDate;
   }

   public X509Extensions getCrlDetails() {
      return this.crlDetails;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.status);
      var1.add(this.certId);
      var1.add(this.willBeRevokedAt);
      var10001.add(this.badSinceDate);
      X509Extensions var2;
      if ((var2 = this.crlDetails) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
